@@ -337,11 +337,14 @@ class Manager(object):
             possible = [config]
         else:
             log.debug('Figuring out config load paths')
-            possible.append(os.getcwd())
+            try:
+                possible.append(os.getcwdu())
+            except OSError:
+                log.debug('current directory invalid, not searching for config there')
             # for virtualenv / dev sandbox
             if hasattr(sys, 'real_prefix'):
                 log.debug('Adding virtualenv path')
-                possible.append(sys.prefix)
+                possible.append(sys.prefix.decode(sys.getfilesystemencoding()))
             # normal lookup locations
             possible.append(home_path)
             if sys.platform.startswith('win'):
